jQuery.extend(true, xcruder, {
	

getGridRow : function(gridId, rowIndex) {
	var table = $("#" + gridId + " table");
	if (!table.length)
		return null;

	return table.find("tbody tr")[rowId];

},

/**
 * Returns an array of data extracted from certain cells from the given row
 * 
 * headSelector: eg "span.__id"
 * indexer : callback function(tdarray, foundh, td)
 **/
getGridCellData : function(gridId, rowIndex, headSelector, indexer ) {

	var table = $("#" + gridId + " > table");
	if (!table.length)
		return null;

	var tr = table.find("> tbody > tr")[rowIndex];
	if (!tr)
		return null;

	if (!indexer) indexer = function(data, foundh, td) {
		data[ foundh.parents('th:first').index() ] = td;
	};
	
	//h may be multiple
	var h = table.find("> thead " + headSelector);
	if (!h.length)
		return null;
	
	var result = {};
	for(var i=0; i<h.length; i++) {
		var cellIndex = $(h[i]).parents('th:first').index();
		//filling result
		indexer.call(this, result, h[i], tr.cells[cellIndex]);
	}
	
	return result;
},

/**
 * Returns the json repr. of the pk
 **/
getGridRowPk : function(gridId, rowIndex) {

	return xcruder.getGridCellData(gridId, rowIndex, "span.pk", function(pk, foundh, td){
		pk[foundh.innerHTML] = td.innerHTML;
	});

},


delCheckedRows : function(gridId) {

	$("#" + gridId + " > table > tbody > tr:has( input:checked )").remove();
	
},


onSingleDelete : function(a, mess) {
	if (!confirm(mess))
		return;
	$(a).parents("table.items:first").find("*[cellIndex=0] input").removeAttr("checked");
	$(a).parents("tr:first").find("*[cellIndex=0] input").attr("checked","checked");
	$(a).parents("form:first").submit();
},


/**
 * must be set as afterAjaxUpdate param of CGridView, eg
 * ...
 * 'afterAjaxUpdate' => 'xcruder.setupGrid("xcruder_browser_grid")'
 * ...
 * 
 * Params:
 *   gridId    id of the grid widget
 *   callback  function(tr){...}  will be called when clicking a row
 * 
 */
setupGrid : function(gridId, onClickCallback) {
	//console.log("setupGrid called...", gridId);

	var table = $("#" + gridId + " > table");
	if (!table.length)
		return null;
	
	table[0].xcruder_pk = undefined;
	var nHeaderRows = table.find(" thead tr").length;
	
	//Assigning click handlers to the rows
	table.find(" > tbody > tr").click(function(e){
		
		//getting row PK
		var pk = xcruder.getGridRowPk(gridId, this.rowIndex - nHeaderRows);
		var lenPk=0,ind=undefined;for(var i in pk) {ind=i;lenPk++;}
		table[0].xcruder_pk = lenPk==1 ? pk[ind] : $.toJSON(pk);
		
		//calling custom callback
		if (onClickCallback)
			onClickCallback.call(table[0], this);
		
	});
	
	table.find(" > tbody > tr > td.button-column a").click(function(e){
		e.stopPropagation();
		if (this.className == 'view') {
			table.find(" > tbody > tr").removeClass("selectedOne");
			$(this.parentNode.parentNode).addClass("selectedOne");
		}

	});

	var multiplePkField = table.parent().find("> input[name=multiplePk]");
	if (!multiplePkField[0]) {
	  table.parent().append("<input type='hidden' name='multiplePk'/>");
	}
	table.parent().find("> input[name=multiplePk]").val( table.find('> thead span.pk').length > 1 ? 1 : 0 );
	
},

setupPickerGrid : function(gridId, fkFieldName) {
	xcruder.setupGrid(gridId, function(tr){
		
		//xcruder.log("tr clicked. ", gridId, fkFieldName, this.xcruder_pk, $(tr).parents("form:first").find("*[name='" + fkFieldName.replace(/[\[\]]/,"\$0") + "']"));

		if (fkFieldName)
			$("form.pickerupdateable:visible *[name='" + fkFieldName + "']").val( this.xcruder_pk );
	});

}

});
